@@ -19,11 +19,12 @@ import typing
 import nox
 
 nox.options.default_venv_backend = "venv"
-nox.options.keywords = "not release"
 nox.options.reuse_existing_virtualenvs = True
 
 PACKAGE_NAME = "webcolors"
 
+IS_CI = bool(os.getenv("CI", False))
+
 NOXFILE_PATH = pathlib.Path(__file__).parents[0]
 ARTIFACT_PATHS = (
     NOXFILE_PATH / "src" / f"{PACKAGE_NAME}.egg-info",
@@ -36,11 +37,15 @@ ARTIFACT_PATHS = (
 )
 
 
-def clean(paths: typing.Iterable[os.PathLike] = ARTIFACT_PATHS) -> None:
+def clean(paths: typing.Iterable[pathlib.Path] = ARTIFACT_PATHS) -> None:
     """
     Clean up after a test run.
 
     """
+    # This cleanup is only useful for the working directory of a local checkout; in CI
+    # we don't need it because CI environments are ephemeral anyway.
+    if IS_CI:
+        return
     [
         shutil.rmtree(path) if path.is_dir() else path.unlink()
         for path in paths
@@ -52,52 +57,67 @@ def clean(paths: typing.Iterable[os.PathLike] = ARTIFACT_PATHS) -> None:
 # -----------------------------------------------------------------------------------
 
 
-@nox.session(python=["3.8", "3.9", "3.10", "3.11", "3.12"], tags=["tests"])
+@nox.session(python=["3.10", "3.11", "3.12", "3.13", "3.14"], tags=["tests"])
 def tests_with_coverage(session: nox.Session) -> None:
     """
-    Run the package's unit tests, with coverage report.
+    Run the package's unit tests, with coverage instrumentation.
 
     """
-    session.install(".[tests]")
+    session.install(".", "pytest", "coverage[toml]")
     session.run(
         f"python{session.python}",
         "-Wonce::DeprecationWarning",
         "-Im",
         "coverage",
         "run",
-        "--source",
-        PACKAGE_NAME,
         "-m",
-        "unittest",
-        "discover",
-    )
-    session.run(
-        f"python{session.python}",
-        "-Im",
-        "coverage",
-        "report",
-        "--show-missing",
+        "pytest",
+        "-vv",
     )
     clean()
 
 
-@nox.session(python=["3.12"], tags=["tests", "release"])
+@nox.session(python=["3.13"], tags=["tests"])
+def coverage_report(session: nox.Session) -> None:
+    """
+    Combine coverage from the various test runs and output the report.
+
+    """
+    # In CI this job does not run because we substitute one that integrates with the CI
+    # system.
+    if IS_CI:
+        session.skip(
+            "Running in CI -- skipping nox coverage job in favor of CI coverage job"
+        )
+    session.install("coverage[toml]")
+    session.run(f"python{session.python}", "-Im", "coverage", "combine")
+    session.run(
+        f"python{session.python}", "-Im", "coverage", "report", "--show-missing"
+    )
+    session.run(f"python{session.python}", "-Im", "coverage", "erase")
+
+
+@nox.session(python=["3.13"], tags=["release"])
 def tests_definitions(session: nox.Session) -> None:
     """
     Run the full color definitions test suite (requires an internet connection).
 
     """
+    if IS_CI:
+        session.skip("Release tests do not run in CI.")
     session.install("pytest", "bs4", "html5lib", "requests", ".[tests]")
     session.run(f"python{session.python}", "-I", "tests/definitions.py")
     clean()
 
 
-@nox.session(python=["3.12"], tags=["tests", "release"])
+@nox.session(python=["3.13"], tags=["release"])
 def tests_full_colors(session: nox.Session) -> None:
     """
     Run the full color conversion test suite (slow/CPU-intensive).
 
     """
+    if IS_CI:
+        session.skip("Release tests do not run in CI.")
     session.install(".[tests]")
     session.run(f"python{session.python}", "-I", "tests/full_colors.py")
     clean()
@@ -107,24 +127,31 @@ def tests_full_colors(session: nox.Session) -> None:
 # -----------------------------------------------------------------------------------
 
 
+# The documentation jobs ordinarily would want to use the latest Python version, but
+# currently that's 3.13 and Read The Docs doesn't yet support it. So to ensure the
+# documentation jobs are as closely matched to what would happen on RTD, these jobs stay
+# on 3.12 for now.
 @nox.session(python=["3.12"], tags=["docs"])
 def docs_build(session: nox.Session) -> None:
     """
     Build the package's documentation as HTML.
 
     """
-    session.install(".[docs]")
-    session.chdir("docs")
+    session.install(".", "-r", "docs/requirements.txt")
+    build_dir = session.create_tmp()
     session.run(
-        f"python{session.python}",
+        f"{session.bin}/python{session.python}",
         "-Im",
         "sphinx",
-        "-b",
+        "--builder",
         "html",
-        "-d",
-        f"{session.bin}/../tmp/doctrees",
-        ".",
-        f"{session.bin}/../tmp/html",
+        "--write-all",
+        "-c",
+        "docs/",
+        "--doctree-dir",
+        f"{build_dir}/doctrees",
+        "docs/",
+        f"{build_dir}/html",
     )
     clean()
 
@@ -136,10 +163,7 @@ def docs_docstrings(session: nox.Session) -> None:
     methods.
 
     """
-    # interrogate implicitly depends on pkg_resources, which is part of setuptools but
-    # as of Python 3.12, the venv module no longer automatically installed setuptools
-    # into newly-created environments. So we install it manually here.
-    session.install("interrogate", "setuptools")
+    session.install("interrogate")
     session.run(f"python{session.python}", "-Im", "interrogate", "--version")
     session.run(
         f"python{session.python}",
@@ -159,23 +183,21 @@ def docs_spellcheck(session: nox.Session) -> None:
     Spell-check the package's documentation.
 
     """
-    session.install(
-        "pyenchant",
-        "sphinxcontrib-spelling",
-        ".[docs]",
-    )
+    session.install(".", "-r", "docs/requirements.txt")
+    session.install("pyenchant", "sphinxcontrib-spelling")
     build_dir = session.create_tmp()
-    session.chdir("docs")
     session.run(
-        f"python{session.python}",
+        f"{session.bin}/python{session.python}",
         "-Im",
         "sphinx",
         "-W",  # Promote warnings to errors, so that misspelled words fail the build.
-        "-b",
+        "--builder",
         "spelling",
-        "-d",
+        "-c",
+        "docs/",
+        "--doctree-dir",
         f"{build_dir}/doctrees",
-        ".",
+        "docs/",
         f"{build_dir}/html",
         # On Apple Silicon Macs, this environment variable needs to be set so
         # pyenchant can find the "enchant" C library. See
@@ -192,13 +214,13 @@ def docs_spellcheck(session: nox.Session) -> None:
 # -----------------------------------------------------------------------------------
 
 
-@nox.session(python=["3.12"], tags=["formatters"])
+@nox.session(python=["3.13"], tags=["formatters"])
 def format_black(session: nox.Session) -> None:
     """
     Check code formatting with Black.
 
     """
-    session.install("black>=24.0,<25.0")
+    session.install("black>=25.0,<26.0")
     session.run(f"python{session.python}", "-Im", "black", "--version")
     session.run(
         f"python{session.python}",
@@ -214,7 +236,7 @@ def format_black(session: nox.Session) -> None:
     clean()
 
 
-@nox.session(python=["3.12"], tags=["formatters"])
+@nox.session(python=["3.13"], tags=["formatters"])
 def format_isort(session: nox.Session) -> None:
     """
     Check import order with isort.
@@ -240,7 +262,7 @@ def format_isort(session: nox.Session) -> None:
 # -----------------------------------------------------------------------------------
 
 
-@nox.session(python=["3.12"], tags=["linters", "security"])
+@nox.session(python=["3.13"], tags=["linters", "security"])
 def lint_bandit(session: nox.Session) -> None:
     """
     Lint code with the Bandit security analyzer.
@@ -261,13 +283,13 @@ def lint_bandit(session: nox.Session) -> None:
     clean()
 
 
-@nox.session(python=["3.12"], tags=["linters"])
+@nox.session(python=["3.13"], tags=["linters"])
 def lint_flake8(session: nox.Session) -> None:
     """
     Lint code with flake8.
 
     """
-    session.install("flake8", "flake8-bugbear")
+    session.install("flake8", "flake8-bugbear", "flake8-pytest-style")
     session.run(f"python{session.python}", "-Im", "flake8", "--version")
     session.run(
         f"python{session.python}",
@@ -281,17 +303,14 @@ def lint_flake8(session: nox.Session) -> None:
     clean()
 
 
-@nox.session(python=["3.12"], tags=["linters"])
+@nox.session(python=["3.13"], tags=["linters"])
 def lint_pylint(session: nox.Session) -> None:
     """
     Lint code with Pylint.
 
     """
-    # Pylint requires that all dependencies be importable during the run. This package
-    # does not have any direct dependencies, nor does the normal test suite, but the
-    # full conformance suite does require a few extra libraries, so they're installed
-    # here.
-    session.install("pylint", "bs4", "html5lib", "requests")
+    # Pylint requires that all dependencies be importable during the run.
+    session.install("pylint", "bs4", "html5lib", "requests", "pytest")
     session.run(f"python{session.python}", "-Im", "pylint", "--version")
     session.run(f"python{session.python}", "-Im", "pylint", "src/", "tests/")
     clean()
@@ -301,7 +320,7 @@ def lint_pylint(session: nox.Session) -> None:
 # -----------------------------------------------------------------------------------
 
 
-@nox.session(python=["3.12"], tags=["packaging"])
+@nox.session(python=["3.13"], tags=["packaging"])
 def package_build(session: nox.Session) -> None:
     """
     Check that the package builds.
@@ -313,7 +332,7 @@ def package_build(session: nox.Session) -> None:
     clean()
 
 
-@nox.session(python=["3.12"], tags=["packaging"])
+@nox.session(python=["3.13"], tags=["packaging"])
 def package_description(session: nox.Session) -> None:
     """
     Check that the package description will render on the Python Package Index.
@@ -337,19 +356,21 @@ def package_description(session: nox.Session) -> None:
     clean()
 
 
-@nox.session(python=["3.12"], tags=["packaging"])
+@nox.session(python=["3.13"], tags=["packaging"])
 def package_manifest(session: nox.Session) -> None:
     """
     Check that the set of files in the package matches the set under version control.
 
     """
+    if IS_CI:
+        session.skip("check-manifest already run by earlier CI steps.")
     session.install("check-manifest")
     session.run(f"python{session.python}", "-Im", "check_manifest", "--version")
     session.run(f"python{session.python}", "-Im", "check_manifest", "--verbose")
     clean()
 
 
-@nox.session(python=["3.12"], tags=["packaging"])
+@nox.session(python=["3.13"], tags=["packaging"])
 def package_pyroma(session: nox.Session) -> None:
     """
     Check package quality with pyroma.
@@ -360,7 +381,7 @@ def package_pyroma(session: nox.Session) -> None:
     clean()
 
 
-@nox.session(python=["3.12"], tags=["packaging"])
+@nox.session(python=["3.13"], tags=["packaging"])
 def package_wheel(session: nox.Session) -> None:
     """
     Check the built wheel package for common errors.
