@@ -1,9 +1,12 @@
 """
-Test accuracy of the mappings of color names and values, by extracting
-the definitions of the colors from the relevant standards documents.
+Test accuracy of the mappings of color names and values, by extracting the
+definitions of the colors from the relevant standards documents.
 
 """
 
+# SPDX-License-Identifier: BSD-3-Clause
+# pylint: disable=protected-access
+
 import re
 import unittest
 
@@ -16,9 +19,8 @@ import webcolors
 
 class HTML4DefinitionTests(unittest.TestCase):
     """
-    Extract the names and values of the 16 defined HTML 4 colors from
-    the online version of the standard, and check them against this
-    module's definitions of them.
+    Extract the names and values of the 16 defined HTML 4 colors from the online
+    version of the standard, and check them against this module's definitions of them.
 
     """
 
@@ -42,20 +44,18 @@ class HTML4DefinitionTests(unittest.TestCase):
 
     def test_color_definitions(self):
         """
-        Ensure the values in this module match those in the HTML 4
-        specification.
+        Ensure the values in this module match those in the HTML 4 specification.
 
         """
         for color_name, color_value in self.html4_colors.items():
-            extracted = webcolors.HTML4_NAMES_TO_HEX[color_name.lower()]
+            extracted = webcolors._definitions._HTML4_NAMES_TO_HEX[color_name.lower()]
             assert color_value.lower() == extracted
 
 
 class CSS21DefinitionTests(unittest.TestCase):
     """
-    Extract the names and values of the 17 defined CSS 2.1 colors from
-    the online version of the standard, and check them against this
-    module's definitions of them.
+    Extract the names and values of the 17 defined CSS 2.1 colors from the online
+    version of the standard, and check them against this module's definitions of them.
 
     """
 
@@ -79,26 +79,25 @@ class CSS21DefinitionTests(unittest.TestCase):
 
     def test_color_definitions(self):
         """
-        Ensure thie values in this module match those in the
-        CSS2.1 specification.
+        Ensure thie values in this module match those in the CSS2.1 specification.
 
         """
         for color_name, color_value in self.css21_colors.items():
-            extracted = webcolors.CSS21_NAMES_TO_HEX[color_name.lower()]
+            extracted = webcolors._definitions._CSS21_NAMES_TO_HEX[color_name.lower()]
             assert color_value.lower() == extracted
 
 
 class CSS3DefinitionTests(unittest.TestCase):
     """
-    Extract the names and values of the 147 defined CSS 3 colors from
-    the online version of the standard, and check them against this
-    module's definitions of them.
+    Extract the names and values of the 147 defined CSS 3 colors from the online
+    version of the standard, and check them against this module's definitions of them.
 
     """
 
     def setUp(self):
         """
         Fetch the CSS3 color definitions and store them on self.css3_colors.
+
         """
         self.css3_colors = {}
         soup = BeautifulSoup(
@@ -131,12 +130,13 @@ class CSS3DefinitionTests(unittest.TestCase):
 
     def test_color_definitions(self):
         """
-        Ensure the values in this module match those in the CSS3
-        specification.
+        Ensure the values in this module match those in the CSS3 specification.
 
         """
         for color_name, color_values in self.css3_colors.items():
-            extracted_hex = webcolors.CSS3_NAMES_TO_HEX[color_name.lower()]
+            extracted_hex = webcolors._definitions._CSS3_NAMES_TO_HEX[
+                color_name.lower()
+            ]
             extracted_rgb = webcolors.name_to_rgb(color_name)
             assert color_values["hex"].lower() == extracted_hex
             assert color_values["rgb"] == extracted_rgb
